var models = require('./models');

function DefaultApi(apiClient) {
    this.apiClient = apiClient;
}

/*
    The list of registered p4d servers in your cluster.

    This is provided by a special set of configuration files in the system.
    For more information, consult the Helix Web Services user guide.

*/
DefaultApi.prototype.configP4dsGet = function configP4dsGet( callback) {
    var query = null;
    var pathParams = null;
    var body = null;
    this.apiClient.executeMethod('get', '/config/p4ds', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.P4dConfigId(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Logs into the primary authentication source.

    This can either be a p4d instance or Helix Cloud, depending upon the
    configuration of your Helix Web Services instance.

*/
DefaultApi.prototype.loginPost = function loginPost(loginRequest, callback) {
    var query = null;
    var pathParams = null;
    var body = loginRequest;
    this.apiClient.executeMethod('post', '/login', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.LoginResponse(response.body);
        callback(null, data);
    });
};
 /*
    A simple structure to monitor for "problems" an admin should take care of, and, report the current application version.

    This method does not require authentication.

*/
DefaultApi.prototype.statusGet = function statusGet( callback) {
    var query = null;
    var pathParams = null;
    var body = null;
    this.apiClient.executeMethod('get', '/status', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.HWSStatus(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new branch specification, like the `p4 branch` command.

*/
DefaultApi.prototype.serverBranchesPost = function serverBranchesPost(server, body, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = body;
    this.apiClient.executeMethod('post', '/{server}/branches', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available branches in the system.
    The resources of this list are summaries of branches in the system.

*/
DefaultApi.prototype.serverBranchesGet = function serverBranchesGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/branches', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.BranchesCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the branch specification, similar to the `p4 branch -d` command.

*/
DefaultApi.prototype.serverBranchesBranchDelete = function serverBranchesBranchDelete(server, branch, callback) {
    var query = null;
    var pathParams = {"server": server, "branch": branch};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/branches/{branch}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update branch specifications, similar to the `p4 branch` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverBranchesBranchPatch = function serverBranchesBranchPatch(server, branch, body, callback) {
    var query = null;
    var pathParams = {"server": server, "branch": branch};
    var body = body;
    this.apiClient.executeMethod('patch', '/{server}/branches/{branch}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the branch spec details of the particular branch.

*/
DefaultApi.prototype.serverBranchesBranchGet = function serverBranchesBranchGet(server, branch, callback) {
    var query = null;
    var pathParams = {"server": server, "branch": branch};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/branches/{branch}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.BranchCommand(response.body);
        callback(null, data);
    });
};
 /*
    Lists available changes in the system.
    The resources of this list are summaries of changes in the system.

*/
DefaultApi.prototype.serverChangesGet = function serverChangesGet(server, max, status, user, files, callback) {
    var query = {"max": max, "status": status, "user": user, "files": files};
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/changes', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.ChangesCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Returns the change spec details of the particular change.

*/
DefaultApi.prototype.serverChangesChangeGet = function serverChangesChangeGet(server, change, callback) {
    var query = null;
    var pathParams = {"server": server, "change": change};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/changes/{change}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.ChangeCommand(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new client specification, like the `p4 client` command.

*/
DefaultApi.prototype.serverClientsPost = function serverClientsPost(server, client, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = client;
    this.apiClient.executeMethod('post', '/{server}/clients', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available clients in the system.
    The resources of this list are summaries of clients in the system.

*/
DefaultApi.prototype.serverClientsGet = function serverClientsGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/clients', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.ClientsCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the client specification, similar to the `p4 client -d` command.

*/
DefaultApi.prototype.serverClientsClientDelete = function serverClientsClientDelete(server, client, callback) {
    var query = null;
    var pathParams = {"server": server, "client": client};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/clients/{client}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update client specifications, similar to the `p4 client` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverClientsClientPatch = function serverClientsClientPatch(server, client, body, callback) {
    var query = null;
    var pathParams = {"server": server, "client": client};
    var body = body;
    this.apiClient.executeMethod('patch', '/{server}/clients/{client}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the client spec details of the particular client.

*/
DefaultApi.prototype.serverClientsClientGet = function serverClientsClientGet(server, client, callback) {
    var query = null;
    var pathParams = {"server": server, "client": client};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/clients/{client}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.ClientCommand(response.body);
        callback(null, data);
    });
};
 /*
    Execute a Perforce command that accepts input, like a spec.
    This only allows commands that have been whitelisted on your system.
    See the <<system_configuration>> section for details.

*/
DefaultApi.prototype.serverCommandsCommandPost = function serverCommandsCommandPost(server, command, arg, input, callback) {
    var query = {"arg": arg};
    var pathParams = {"server": server, "command": command};
    var body = input;
    this.apiClient.executeMethod('post', '/{server}/commands/{command}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Execute a Perforce command that requires no input.
    This only allows commands that have been whitelisted on your system.
    See the <<system_configuration>> section for details.

*/
DefaultApi.prototype.serverCommandsCommandGet = function serverCommandsCommandGet(server, command, arg, callback) {
    var query = {"arg": arg};
    var pathParams = {"server": server, "command": command};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/commands/{command}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available counters in the system.
    The resources of this list are summaries of counters in the system.

*/
DefaultApi.prototype.serverCountersGet = function serverCountersGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/counters', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.Counter(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the counter specification, similar to the `p4 counter -d` command.

*/
DefaultApi.prototype.serverCountersCounterDelete = function serverCountersCounterDelete(server, counter, callback) {
    var query = null;
    var pathParams = {"server": server, "counter": counter};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/counters/{counter}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the counter spec details of the particular counter.

*/
DefaultApi.prototype.serverCountersCounterGet = function serverCountersCounterGet(server, counter, callback) {
    var query = null;
    var pathParams = {"server": server, "counter": counter};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/counters/{counter}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.Counter(response.body);
        callback(null, data);
    });
};
 /*
    Update counter specifications, similar to the `p4 counter` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverCountersCounterPut = function serverCountersCounterPut(server, counter, body, callback) {
    var query = null;
    var pathParams = {"server": server, "counter": counter};
    var body = body;
    this.apiClient.executeMethod('put', '/{server}/counters/{counter}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Increments a numerical counter, similar to the `p4 counter -i` command.

*/
DefaultApi.prototype.serverCountersCounterIncrementPost = function serverCountersCounterIncrementPost(server, counter, callback) {
    var query = null;
    var pathParams = {"server": server, "counter": counter};
    var body = null;
    this.apiClient.executeMethod('post', '/{server}/counters/{counter}/increment', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new depot specification, like the `p4 depot` command.

*/
DefaultApi.prototype.serverDepotsPost = function serverDepotsPost(server, depot, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = depot;
    this.apiClient.executeMethod('post', '/{server}/depots', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available depots in the system.
    The resources of this list are summaries of depots in the system.

*/
DefaultApi.prototype.serverDepotsGet = function serverDepotsGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/depots', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.DepotsCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the depot specification, similar to the `p4 depot -d` command.

*/
DefaultApi.prototype.serverDepotsDepotDelete = function serverDepotsDepotDelete(server, depot, callback) {
    var query = null;
    var pathParams = {"server": server, "depot": depot};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/depots/{depot}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update depot specifications, similar to the `p4 depot` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverDepotsDepotPatch = function serverDepotsDepotPatch(server, depot, body, callback) {
    var query = null;
    var pathParams = {"server": server, "depot": depot};
    var body = body;
    this.apiClient.executeMethod('patch', '/{server}/depots/{depot}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the depot spec details of the particular depot.

*/
DefaultApi.prototype.serverDepotsDepotGet = function serverDepotsDepotGet(server, depot, callback) {
    var query = null;
    var pathParams = {"server": server, "depot": depot};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/depots/{depot}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.DepotCommand(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new group specification, like the `p4 group` command.

*/
DefaultApi.prototype.serverGroupsPost = function serverGroupsPost(server, body, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = body;
    this.apiClient.executeMethod('post', '/{server}/groups', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available groups in the system.
    The resources of this list are summaries of groups in the system.

*/
DefaultApi.prototype.serverGroupsGet = function serverGroupsGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/groups', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.GroupsCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the group specification, similar to the `p4 group -d` command.

*/
DefaultApi.prototype.serverGroupsGroupDelete = function serverGroupsGroupDelete(server, group, callback) {
    var query = null;
    var pathParams = {"server": server, "group": group};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/groups/{group}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update group specifications, similar to the `p4 group` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverGroupsGroupPatch = function serverGroupsGroupPatch(server, group, body, callback) {
    var query = null;
    var pathParams = {"server": server, "group": group};
    var body = body;
    this.apiClient.executeMethod('patch', '/{server}/groups/{group}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the group spec details of the particular group.

*/
DefaultApi.prototype.serverGroupsGroupGet = function serverGroupsGroupGet(server, group, callback) {
    var query = null;
    var pathParams = {"server": server, "group": group};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/groups/{group}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.GroupCommand(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new job specification, like the `p4 job` command.

*/
DefaultApi.prototype.serverJobsPost = function serverJobsPost(server, job, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = job;
    this.apiClient.executeMethod('post', '/{server}/jobs', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available jobs in the system.
    The resources of this list are summaries of jobs in the system.

*/
DefaultApi.prototype.serverJobsGet = function serverJobsGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/jobs', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.JobsCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the job specification, similar to the `p4 job -d` command.

*/
DefaultApi.prototype.serverJobsJobDelete = function serverJobsJobDelete(server, job, callback) {
    var query = null;
    var pathParams = {"server": server, "job": job};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/jobs/{job}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update job specifications, similar to the `p4 job` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverJobsJobPatch = function serverJobsJobPatch(server, job, jobCommand, callback) {
    var query = null;
    var pathParams = {"server": server, "job": job};
    var body = jobCommand;
    this.apiClient.executeMethod('patch', '/{server}/jobs/{job}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the job spec details of the particular job.

*/
DefaultApi.prototype.serverJobsJobGet = function serverJobsJobGet(server, job, callback) {
    var query = null;
    var pathParams = {"server": server, "job": job};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/jobs/{job}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.JobCommand(response.body);
        callback(null, data);
    });
};
 /*
    Adds a fix record to the job for a particular changelist.

*/
DefaultApi.prototype.serverJobsJobFixesChangePost = function serverJobsJobFixesChangePost(server, job, change, status, callback) {
    var query = {"status": status};
    var pathParams = {"server": server, "job": job, "change": change};
    var body = null;
    this.apiClient.executeMethod('post', '/{server}/jobs/{job}/fixes/{change}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Removes the fix record association for the job for a particular changelist.

*/
DefaultApi.prototype.serverJobsJobFixesChangeDelete = function serverJobsJobFixesChangeDelete(server, job, change, callback) {
    var query = null;
    var pathParams = {"server": server, "job": job, "change": change};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/jobs/{job}/fixes/{change}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new label specification, like the `p4 label` command.

*/
DefaultApi.prototype.serverLabelsPost = function serverLabelsPost(server, label, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = label;
    this.apiClient.executeMethod('post', '/{server}/labels', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available labels in the system.
    The resources of this list are summaries of labels in the system.

*/
DefaultApi.prototype.serverLabelsGet = function serverLabelsGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/labels', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.LabelsCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the label specification, similar to the `p4 label -d` command.

*/
DefaultApi.prototype.serverLabelsLabelDelete = function serverLabelsLabelDelete(server, label, callback) {
    var query = null;
    var pathParams = {"server": server, "label": label};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/labels/{label}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update label specifications, similar to the `p4 label` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverLabelsLabelPatch = function serverLabelsLabelPatch(server, label, labelCommand, callback) {
    var query = null;
    var pathParams = {"server": server, "label": label};
    var body = labelCommand;
    this.apiClient.executeMethod('patch', '/{server}/labels/{label}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the label spec details of the particular label.

*/
DefaultApi.prototype.serverLabelsLabelGet = function serverLabelsLabelGet(server, label, callback) {
    var query = null;
    var pathParams = {"server": server, "label": label};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/labels/{label}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.LabelCommand(response.body);
        callback(null, data);
    });
};
 /*
    Logs into a Helix Versioning Engine (p4d) server.

*/
DefaultApi.prototype.serverLoginPost = function serverLoginPost(server, body, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = body;
    this.apiClient.executeMethod('post', '/{server}/login', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.LoginResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists depots, files, and directories in the system.
    This combines the output of the `p4 depots`, `p4 dirs`, and `p4 files` commands, depending upon your path.

*/
DefaultApi.prototype.serverPathsGet = function serverPathsGet(server, path, callback) {
    var query = {"path": path};
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/paths', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.Location(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Returns a list of available protections in the system.
    The elements of this list are rows of the system's protections table.

    This method requires superuser access.

    See the output of http://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_protect.html[`p4 protect`] for more information.

*/
DefaultApi.prototype.serverProtectionsGet = function serverProtectionsGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/protections', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.Protections(response.body);
        callback(null, data);
    });
};
 /*
    Updates the protections table.

    This method requires superuser access.

*/
DefaultApi.prototype.serverProtectionsPut = function serverProtectionsPut(server, protections, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = protections;
    this.apiClient.executeMethod('put', '/{server}/protections', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new server specification, like the `p4 server` command.

*/
DefaultApi.prototype.serverServersPost = function serverServersPost(server, serverCommand, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = serverCommand;
    this.apiClient.executeMethod('post', '/{server}/servers', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available servers in the system.
    The resources of this list are summaries of servers in the system.

*/
DefaultApi.prototype.serverServersGet = function serverServersGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/servers', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.ServersCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the server specification, similar to the `p4 server -d` command.

*/
DefaultApi.prototype.serverServersServerIdDelete = function serverServersServerIdDelete(server, serverId, callback) {
    var query = null;
    var pathParams = {"server": server, "serverId": serverId};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/servers/{serverId}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update server specifications, similar to the `p4 server` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverServersServerIdPatch = function serverServersServerIdPatch(server, serverId, serverCommand, callback) {
    var query = null;
    var pathParams = {"server": server, "serverId": serverId};
    var body = serverCommand;
    this.apiClient.executeMethod('patch', '/{server}/servers/{serverId}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the server spec details of the particular server.

*/
DefaultApi.prototype.serverServersServerIdGet = function serverServersServerIdGet(server, serverId, callback) {
    var query = null;
    var pathParams = {"server": server, "serverId": serverId};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/servers/{serverId}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.ServerCommand(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new stream specification, like the `p4 stream` command.

*/
DefaultApi.prototype.serverStreamsPost = function serverStreamsPost(server, body, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = body;
    this.apiClient.executeMethod('post', '/{server}/streams', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available streams in the system.
    The resources of this list are summaries of streams in the system.

*/
DefaultApi.prototype.serverStreamsGet = function serverStreamsGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/streams', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.StreamsCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the stream specification, similar to the `p4 stream -d` command.

*/
DefaultApi.prototype.serverStreamsStreamDelete = function serverStreamsStreamDelete(server, stream, callback) {
    var query = {"stream": stream};
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/streams/stream', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update stream specifications, similar to the `p4 stream` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverStreamsStreamPatch = function serverStreamsStreamPatch(server, stream, body, callback) {
    var query = {"stream": stream};
    var pathParams = {"server": server};
    var body = body;
    this.apiClient.executeMethod('patch', '/{server}/streams/stream', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the stream spec details of the particular stream.

*/
DefaultApi.prototype.serverStreamsStreamGet = function serverStreamsStreamGet(server, stream, callback) {
    var query = {"stream": stream};
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/streams/stream', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.StreamCommand(response.body);
        callback(null, data);
    });
};
 /*
    Returns a list of available triggers in the system.
    The elements of this list are rows of the system's triggers table.

    This method requires superuser access.

*/
DefaultApi.prototype.serverTriggersGet = function serverTriggersGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/triggers', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.Triggers(response.body);
        callback(null, data);
    });
};
 /*
    Updates the triggers table.

    This method requires superuser access.

*/
DefaultApi.prototype.serverTriggersPut = function serverTriggersPut(server, triggers, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = triggers;
    this.apiClient.executeMethod('put', '/{server}/triggers', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Creates a new user specification, like the `p4 user` command.

*/
DefaultApi.prototype.serverUsersPost = function serverUsersPost(server, body, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = body;
    this.apiClient.executeMethod('post', '/{server}/users', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists available users in the system.
    The resources of this list are summaries of users in the system.

*/
DefaultApi.prototype.serverUsersGet = function serverUsersGet(server, includeService, max, callback) {
    var query = {"includeService": includeService, "max": max};
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/users', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.UsersCommand(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Removes the user specification, similar to the `p4 user -d` command.

*/
DefaultApi.prototype.serverUsersUserDelete = function serverUsersUserDelete(server, user, callback) {
    var query = null;
    var pathParams = {"server": server, "user": user};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/users/{user}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Update user specifications, similar to the `p4 user` command.
    Only the specified parameters in the body will be changed.

*/
DefaultApi.prototype.serverUsersUserPatch = function serverUsersUserPatch(server, user, body, callback) {
    var query = null;
    var pathParams = {"server": server, "user": user};
    var body = body;
    this.apiClient.executeMethod('patch', '/{server}/users/{user}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Returns the user spec details of the particular user.

*/
DefaultApi.prototype.serverUsersUserGet = function serverUsersUserGet(server, user, callback) {
    var query = null;
    var pathParams = {"server": server, "user": user};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/users/{user}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.UserCommand(response.body);
        callback(null, data);
    });
};
 

module.exports = DefaultApi;
