/*
*/
function ChangesCommand(data) {

    Object.defineProperties(this, {
        /*
          The changelist ID
        */
        "change": {
            value: data ? data.change : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Last modification time of the changelist
        */
        "date": {
            enumerable: true,
            get: function() {
                if (data && data.date) {
                    var strVal = data.date;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          The owner of the changelist
        */
        "user": {
            value: data ? data.user : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Name of current client workspace.
        */
        "client": {
            value: data ? data.client : undefined,
            enumerable: true,
            writable: true
        },
        /*
          `pending`, `shelved`, `submitted`, or `new`.
          Not editable by the user.

          The status is `new` when the changelist is created, `pending` when it has been created but has not yet been submitted to the depot, `shelved` when its contents are shelved, and `submitted` when its contents have been stored in the depot.

        */
        "status": {
            value: data ? data.status : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Type of change: `restricted` or `public`.

          The Type: field can be used to hide the change or its description from users.
          A shelved or committed change (as denoted in the Status: field) that is restricted is accessible only to users who own the change or have list permission to at least one file in the change.

          Public changes are displayed without restrictions.

          By default, changelists are public.
          A Perforce superuser can set the default changelist type (for changelists created after the configurable is set) by setting the defaultChangeType configurable.

        */
        "type": {
            value: data ? data.type : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Depot paths affected by this changelist
        */
        "path": {
            value: data ? data.path : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Textual description of changelist.

          If you do not have access to a restricted changelist, the description is replaced with a "no permission" message.

        */
        "description": {
            value: data ? data.description : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = ChangesCommand;
